@@ -282,12 +282,12 @@ def test_space_server_settings_twrelease():
 
     response, content = http.request('http://foo.0.0.0.0:8080/')
     assert response['status'] == '200', content
-    assert '/bags/common/tiddlers/jquery.js' in content
+    assert '/bags/common/tiddlers/twjquery.js' in content
 
     response, content = http.request('http://foo.0.0.0.0:8080/tiddlers',
             headers={'Accept': 'text/x-tiddlywiki'})
     assert response['status'] == '200'
-    assert '/bags/common/tiddlers/jquery.js' in content
+    assert '/bags/common/tiddlers/twjquery.js' in content
     assert '/bags/common/tiddlers/twcore.js' in content
     assert 'TiddlyWiki created by Jeremy Ruston' in content
 
